.. :changelog:

History
-------

0.1.4.6 (2021-09-16)
++++++++++++++++++++++

* 5c6aace - Fix bug when add holiday but not same name but exist

0.1.4.5 (2021-09-16)
++++++++++++++++++++++

* f1a0bfd - Add system to select year for holiday change system for create holiday

0.1.4.4 (2021-09-16)
++++++++++++++++++++++

* 7da006a - fix error import in view for admin

0.1.4.3 (2021-09-14)
++++++++++++++++++++++

* Update requirements
* dfcaaa6 - add mixins to block user not connected and update context for compatibility

0.1.4.2 (2021-07-20)
++++++++++++++++++++++

* Update requirements
* 518f8e3 - Fix for new django version
* 93cba01 - Add tracker to Holiday and OrganisationClosure

0.1.4.1 (2021-06-07)
++++++++++++++++++++

* Update requirements
* Update django for security fix

0.1.4 (2021-04-12)
++++++++++++++++++

* Update requirements

0.1.3 (2020-10-12)
++++++++++++++++++

* Fix bug in migrate
* Add traduction FR in package

0.1.2 (2020-10-07)
++++++++++++++++++

* Fix test for use

0.1.1 (2020-10-06)
++++++++++++++++++

* Add organisation & Organisation closure
* Restruct package for better comprehension
* Add tests

0.1.0 (2020-10-06)
++++++++++++++++++

* First release on PyPI.
